searchData={"items":[{"type":"module","title":"CozySize","doc":"Provides utilities for sizes.\n\nCurrently, there're three existing standards for prefixing units of sizes:\n\n  * SI\n  * IEC\n  * JEDEC\n\n> Read more about them at  .\n\n`CozySize` provides support for them via:\n\n  * `CozySize.SI`\n  * `CozySize.IEC`\n  * `CozySize.JEDEC`","ref":"CozySize.html"},{"type":"module","title":"Usage - CozySize","doc":"iex> # get bytes by following IEC standard\n    iex> bytes = CozySize.IEC.to_bytes({1024, :MiB})\n    iex> # get a humanized tuple by following IEC standard\n    iex> CozySize.IEC.from_bytes(bytes)\n    {1, :GiB}\n    iex> # get a humanized tuple by following JEDEC standard\n    iex> CozySize.JEDEC.from_bytes(bytes)\n    {1, :GB}\n    iex> # get a humanized tuple by following JEDEC standard\n    iex> CozySize.SI.from_bytes(bytes)\n    {1.07, :GB}\n\nIf you want to operate on bits, please check the `*_bits` functions in each\nmodule, which will not be further elaborated here.","ref":"CozySize.html#module-usage"},{"type":"module","title":"Note - CozySize","doc":"I know there are many repetitive parts in the code, but I don't plan to\nabstract them. The abstracted code might not be as easy to understand,\nso I intend to leave them as they are.","ref":"CozySize.html#module-note"},{"type":"type","title":"CozySize.bits/0","doc":"","ref":"CozySize.html#t:bits/0"},{"type":"type","title":"CozySize.bytes/0","doc":"","ref":"CozySize.html#t:bytes/0"},{"type":"type","title":"CozySize.from_opt/0","doc":"","ref":"CozySize.html#t:from_opt/0"},{"type":"type","title":"CozySize.from_opts/0","doc":"","ref":"CozySize.html#t:from_opts/0"},{"type":"module","title":"CozySize.IEC","doc":"Provides utilities for sizes using IEC-prefixed units.","ref":"CozySize.IEC.html"},{"type":"function","title":"CozySize.IEC.from_bits/2","doc":"Converts a number of bits to a `{n, unit}` tuple.","ref":"CozySize.IEC.html#from_bits/2"},{"type":"function","title":"Examples - CozySize.IEC.from_bits/2","doc":"iex> CozySize.IEC.from_bits(8, as: :bits)\n    {8, :b}\n\n    iex> CozySize.IEC.from_bits(8192, as: :bits)\n    {8, :Kib}\n\n    iex> CozySize.IEC.from_bits(2 ** 100, as: :bits)\n    {1048576, :Yib}\n\n    iex> CozySize.IEC.from_bits(1024 * 10 ** 11, as: :bits)\n    {93.13, :Tib}\n\n    iex> CozySize.IEC.from_bits(1024 * 10 ** 11, as: :bits, precision: 4)\n    {93.1323, :Tib}\n\n    iex> CozySize.IEC.from_bits(8, as: :bytes)\n    {1, :B}\n\n    iex> CozySize.IEC.from_bits(8192, as: :bytes)\n    {1, :KiB}\n\n    iex> CozySize.IEC.from_bits(2 ** 100, as: :bytes)\n    {131072, :YiB}\n\n    iex> CozySize.IEC.from_bits(1024 * 10 ** 11, as: :bytes)\n    {11.64, :TiB}\n\n    iex> CozySize.IEC.from_bits(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {11.6415, :TiB}","ref":"CozySize.IEC.html#from_bits/2-examples"},{"type":"function","title":"CozySize.IEC.from_bytes/2","doc":"Converts a number of bytes to a `{n, unit}` tuple.","ref":"CozySize.IEC.html#from_bytes/2"},{"type":"function","title":"Examples - CozySize.IEC.from_bytes/2","doc":"iex> CozySize.IEC.from_bytes(8, as: :bits)\n    {64, :b}\n\n    iex> CozySize.IEC.from_bytes(8192, as: :bits)\n    {64, :Kib}\n\n    iex> CozySize.IEC.from_bytes(2 ** 100, as: :bits)\n    {8388608, :Yib}\n\n    iex> CozySize.IEC.from_bytes(1024 * 10 ** 11, as: :bits)\n    {745.06, :Tib}\n\n    iex> CozySize.IEC.from_bytes(1024 * 10 ** 11, as: :bits, precision: 4)\n    {745.0581, :Tib}\n\n    iex> CozySize.IEC.from_bytes(8, as: :bytes)\n    {8, :B}\n\n    iex> CozySize.IEC.from_bytes(8192, as: :bytes)\n    {8, :KiB}\n\n    iex> CozySize.IEC.from_bytes(2 ** 100, as: :bytes)\n    {1048576, :YiB}\n\n    iex> CozySize.IEC.from_bytes(1024 * 10 ** 11, as: :bytes)\n    {93.13, :TiB}\n\n    iex> CozySize.IEC.from_bytes(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {93.1323, :TiB}","ref":"CozySize.IEC.html#from_bytes/2-examples"},{"type":"function","title":"CozySize.IEC.to_bits/1","doc":"Converts a `{n, unit}` tuple to a number of bits.","ref":"CozySize.IEC.html#to_bits/1"},{"type":"function","title":"Examples - CozySize.IEC.to_bits/1","doc":"iex> CozySize.IEC.to_bits({1, :b})\n    1\n\n    iex> CozySize.IEC.to_bits({1, :Kib})\n    1024\n\n    iex> CozySize.IEC.to_bits({1.1, :Kib})\n    1126.4\n\n    iex> CozySize.IEC.to_bits({1, :B})\n    8\n\n    iex> CozySize.IEC.to_bits({1, :KiB})\n    8192\n\n    iex> CozySize.IEC.to_bits({1.1, :KiB})\n    9011.2","ref":"CozySize.IEC.html#to_bits/1-examples"},{"type":"function","title":"CozySize.IEC.to_bytes/1","doc":"Converts a `{n, unit}` tuple to a number of bytes.","ref":"CozySize.IEC.html#to_bytes/1"},{"type":"function","title":"Examples - CozySize.IEC.to_bytes/1","doc":"iex> CozySize.IEC.to_bytes({1, :b})\n    0.125\n\n    iex> CozySize.IEC.to_bytes({1, :Kib})\n    128\n\n    iex> CozySize.IEC.to_bytes({1.1, :Kib})\n    140.8\n\n    iex> CozySize.IEC.to_bytes({1, :B})\n    1\n\n    iex> CozySize.IEC.to_bytes({1, :KiB})\n    1024\n\n    iex> CozySize.IEC.to_bytes({1.1, :KiB})\n    1126.4","ref":"CozySize.IEC.html#to_bytes/1-examples"},{"type":"type","title":"CozySize.IEC.unit/0","doc":"","ref":"CozySize.IEC.html#t:unit/0"},{"type":"module","title":"CozySize.JEDEC","doc":"Provides utilities for sizes using JEDEC-prefixed units.","ref":"CozySize.JEDEC.html"},{"type":"function","title":"CozySize.JEDEC.from_bits/2","doc":"Converts a number of bits to a `{n, unit}` tuple.","ref":"CozySize.JEDEC.html#from_bits/2"},{"type":"function","title":"Examples - CozySize.JEDEC.from_bits/2","doc":"iex> CozySize.JEDEC.from_bits(8, as: :bits)\n    {8, :b}\n\n    iex> CozySize.JEDEC.from_bits(8192, as: :bits)\n    {8, :Kb}\n\n    iex> CozySize.JEDEC.from_bits(2 ** 100, as: :bits)\n    {1152921504606846976, :Tb}\n\n    iex> CozySize.JEDEC.from_bits(1024 * 10 ** 11, as: :bits)\n    {93.13, :Tb}\n\n    iex> CozySize.JEDEC.from_bits(1024 * 10 ** 11, as: :bits, precision: 4)\n    {93.1323, :Tb}\n\n    iex> CozySize.JEDEC.from_bits(8, as: :bytes)\n    {1, :B}\n\n    iex> CozySize.JEDEC.from_bits(8192, as: :bytes)\n    {1, :KB}\n\n    iex> CozySize.JEDEC.from_bits(2 ** 100, as: :bytes)\n    {144115188075855872, :TB}\n\n    iex> CozySize.JEDEC.from_bits(1024 * 10 ** 11, as: :bytes)\n    {11.64, :TB}\n\n    iex> CozySize.JEDEC.from_bits(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {11.6415, :TB}","ref":"CozySize.JEDEC.html#from_bits/2-examples"},{"type":"function","title":"CozySize.JEDEC.from_bytes/2","doc":"Converts a number of bytes to a `{n, unit}` tuple.","ref":"CozySize.JEDEC.html#from_bytes/2"},{"type":"function","title":"Examples - CozySize.JEDEC.from_bytes/2","doc":"iex> CozySize.JEDEC.from_bytes(8, as: :bits)\n    {64, :b}\n\n    iex> CozySize.JEDEC.from_bytes(8192, as: :bits)\n    {64, :Kb}\n\n    iex> CozySize.JEDEC.from_bytes(2 ** 100, as: :bits)\n    {9223372036854775808, :Tb}\n\n    iex> CozySize.JEDEC.from_bytes(1024 * 10 ** 11, as: :bits)\n    {745.06, :Tb}\n\n    iex> CozySize.JEDEC.from_bytes(1024 * 10 ** 11, as: :bits, precision: 4)\n    {745.0581, :Tb}\n\n    iex> CozySize.JEDEC.from_bytes(8, as: :bytes)\n    {8, :B}\n\n    iex> CozySize.JEDEC.from_bytes(8192, as: :bytes)\n    {8, :KB}\n\n    iex> CozySize.JEDEC.from_bytes(2 ** 100, as: :bytes)\n    {1152921504606846976, :TB}\n\n    iex> CozySize.JEDEC.from_bytes(1024 * 10 ** 11, as: :bytes)\n    {93.13, :TB}\n\n    iex> CozySize.JEDEC.from_bytes(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {93.1323, :TB}","ref":"CozySize.JEDEC.html#from_bytes/2-examples"},{"type":"function","title":"CozySize.JEDEC.to_bits/1","doc":"Converts a `{n, unit}` tuple to a number of bits.","ref":"CozySize.JEDEC.html#to_bits/1"},{"type":"function","title":"Examples - CozySize.JEDEC.to_bits/1","doc":"iex> CozySize.JEDEC.to_bits({1, :b})\n    1\n\n    iex> CozySize.JEDEC.to_bits({1, :Kb})\n    1024\n\n    iex> CozySize.JEDEC.to_bits({1.1, :Kb})\n    1126.4\n\n    iex> CozySize.JEDEC.to_bits({1, :B})\n    8\n\n    iex> CozySize.JEDEC.to_bits({1, :KB})\n    8192\n\n    iex> CozySize.JEDEC.to_bits({1.1, :KB})\n    9011.2","ref":"CozySize.JEDEC.html#to_bits/1-examples"},{"type":"function","title":"CozySize.JEDEC.to_bytes/1","doc":"Converts a `{n, unit}` tuple to a number of bytes.","ref":"CozySize.JEDEC.html#to_bytes/1"},{"type":"function","title":"Examples - CozySize.JEDEC.to_bytes/1","doc":"iex> CozySize.JEDEC.to_bytes({1, :b})\n    0.125\n\n    iex> CozySize.JEDEC.to_bytes({1, :Kb})\n    128\n\n    iex> CozySize.JEDEC.to_bytes({1.1, :Kb})\n    140.8\n\n    iex> CozySize.JEDEC.to_bytes({1, :B})\n    1\n\n    iex> CozySize.JEDEC.to_bytes({1, :KB})\n    1024\n\n    iex> CozySize.JEDEC.to_bytes({1.1, :KB})\n    1126.4","ref":"CozySize.JEDEC.html#to_bytes/1-examples"},{"type":"type","title":"CozySize.JEDEC.unit/0","doc":"","ref":"CozySize.JEDEC.html#t:unit/0"},{"type":"module","title":"CozySize.SI","doc":"Provides utilities for sizes using SI-prefixed units.","ref":"CozySize.SI.html"},{"type":"function","title":"CozySize.SI.from_bits/2","doc":"Converts a number of bits to a `{n, unit}` tuple.","ref":"CozySize.SI.html#from_bits/2"},{"type":"function","title":"Examples - CozySize.SI.from_bits/2","doc":"iex> CozySize.SI.from_bits(8, as: :bits)\n    {8, :b}\n\n    iex> CozySize.SI.from_bits(8192, as: :bits)\n    {8.19, :kb}\n\n    iex> CozySize.SI.from_bits(2 ** 120, as: :bits)\n    {1329228, :Qb}\n\n    iex> CozySize.SI.from_bits(1024 * 10 ** 11, as: :bits)\n    {102.4, :Tb}\n\n    iex> CozySize.SI.from_bits(1024 * 10 ** 11, as: :bits, precision: 4)\n    {102.4, :Tb}\n\n    iex> CozySize.SI.from_bits(8, as: :bytes)\n    {1, :B}\n\n    iex> CozySize.SI.from_bits(8192, as: :bytes)\n    {1.02, :kB}\n\n    iex> CozySize.SI.from_bits(2 ** 120, as: :bytes)\n    {166153.5, :QB}\n\n    iex> CozySize.SI.from_bits(1024 * 10 ** 11, as: :bytes)\n    {12.8, :TB}\n\n    iex> CozySize.SI.from_bits(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {12.8, :TB}","ref":"CozySize.SI.html#from_bits/2-examples"},{"type":"function","title":"CozySize.SI.from_bytes/2","doc":"Converts a number of bytes to a `{n, unit}` tuple.","ref":"CozySize.SI.html#from_bytes/2"},{"type":"function","title":"Examples - CozySize.SI.from_bytes/2","doc":"iex> CozySize.SI.from_bytes(8, as: :bits)\n    {64, :b}\n\n    iex> CozySize.SI.from_bytes(8192, as: :bits)\n    {65.54, :kb}\n\n    iex> CozySize.SI.from_bytes(2 ** 120, as: :bits)\n    {10633823.97, :Qb}\n\n    iex> CozySize.SI.from_bytes(1024 * 10 ** 11, as: :bits)\n    {819.2, :Tb}\n\n    iex> CozySize.SI.from_bytes(1024 * 10 ** 11, as: :bits, precision: 4)\n    {819.2, :Tb}\n\n    iex> CozySize.SI.from_bytes(8, as: :bytes)\n    {8, :B}\n\n    iex> CozySize.SI.from_bytes(8192, as: :bytes)\n    {8.19, :kB}\n\n    iex> CozySize.SI.from_bytes(2 ** 120, as: :bytes)\n    {1329228, :QB}\n\n    iex> CozySize.SI.from_bytes(1024 * 10 ** 11, as: :bytes)\n    {102.4, :TB}\n\n    iex> CozySize.SI.from_bytes(1024 * 10 ** 11, as: :bytes, precision: 4)\n    {102.4, :TB}","ref":"CozySize.SI.html#from_bytes/2-examples"},{"type":"function","title":"CozySize.SI.to_bits/1","doc":"Converts a `{n, unit}` tuple to a number of bits.","ref":"CozySize.SI.html#to_bits/1"},{"type":"function","title":"Examples - CozySize.SI.to_bits/1","doc":"iex> CozySize.SI.to_bits({1, :b})\n    1\n\n    iex> CozySize.SI.to_bits({1, :kb})\n    1000\n\n    iex> CozySize.SI.to_bits({1.1, :kb})\n    1100\n\n    iex> CozySize.SI.to_bits({1, :B})\n    8\n\n    iex> CozySize.SI.to_bits({1, :kB})\n    8000\n\n    iex> CozySize.SI.to_bits({1.1, :kB})\n    8800","ref":"CozySize.SI.html#to_bits/1-examples"},{"type":"function","title":"CozySize.SI.to_bytes/1","doc":"Converts a `{n, unit}` tuple to a number of bytes.","ref":"CozySize.SI.html#to_bytes/1"},{"type":"function","title":"Examples - CozySize.SI.to_bytes/1","doc":"iex> CozySize.SI.to_bytes({1, :b})\n    0.125\n\n    iex> CozySize.SI.to_bytes({1, :kb})\n    125\n\n    iex> CozySize.SI.to_bytes({1.1, :kb})\n    137.5\n\n    iex> CozySize.SI.to_bytes({1, :B})\n    1\n\n    iex> CozySize.SI.to_bytes({1, :kB})\n    1000\n\n    iex> CozySize.SI.to_bytes({1.1, :kB})\n    1100","ref":"CozySize.SI.html#to_bytes/1-examples"},{"type":"type","title":"CozySize.SI.unit/0","doc":"","ref":"CozySize.SI.html#t:unit/0"},{"type":"extras","title":"CozySize","doc":"# CozySize\n\n[![CI](https://github.com/cozy-elixir/cozy_size/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_size/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_size.svg)](https://hex.pm/packages/cozy_size)\n\nProvides utilities for sizes.","ref":"readme.html"},{"type":"extras","title":"Installation - CozySize","doc":"Add `:cozy_size` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cozy_size,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozySize","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_size).\n\n<!---\n\n  There are several packages in community.\n\n  + https://github.com/jfcalvo/size\n  + https://github.com/arvidkahl/sizeable\n  + https://github.com/slickcoach/filesize\n  + https://github.com/tlux/file_size\n\n  They are either poorly designed or too complex. In any case,\n  I don't like them.\n\n-->","ref":"readme.html#usage"},{"type":"extras","title":"License - CozySize","doc":"[Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0)","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}